@@ -14,6 +14,7 @@ DISABLE_PROTECTION = "_disable_protection"
 SPECIAL_ATTRIBUTES = {
     REQUIRED_FIELDS,
     ADDITIONAL_PROPERTIES,
+    OLD_ADDITIONAL_PROPERTIES,
     IS_IMMUTABLE,
     DEFAULTS,
     OPTIONAL_FIELDS,
@@ -22,5 +23,6 @@ SPECIAL_ATTRIBUTES = {
     IGNORE_NONE_VALUES,
     ENABLE_UNDEFINED,
 }
+CUSTOM_ATTRIBUTE_MARKER = "_custom_attribute_"
 MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS = 100000
 INDEX = "    "
