@@ -339,7 +339,20 @@ def get_additional_structure_methods(
             f"{params_with_cls}{kw_opt}\n{INDENT}): ...",
         ]
     )
-    return "\n".join([shallow_clone, from_other_class])
+    params_with_cls_none_default = f",\n{INDENT * 2}".join(
+        [f"{INDENT}cls", "source_object: Any = None", "*"]
+        + ["ignore_props: Iterable[str] = None"]
+        + params
+    )
+    from_trusted_data = f"\n{INDENT}".join(
+        [
+            "",
+            "@classmethod",
+            "def from_trusted_data(",
+            f"{params_with_cls_none_default}{kw_opt}\n{INDENT}): ...",
+        ]
+    )
+    return "\n".join([shallow_clone, from_other_class, from_trusted_data])
 
 
 def get_init(cls, ordered_args: dict, additional_properties_default: bool) -> str:
